@@ -82,7 +82,7 @@ extern int main_debug;
     MAIN_EMPTY = -2,
     MAIN_EOF = 0,                  /* "end of file"  */
     MAIN_error = 256,              /* error  */
-    MAIN_UNDEF = 10523,            /* "invalid token"  */
+    MAIN_UNDEF = 10531,            /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -94,36 +94,42 @@ extern int main_debug;
     LL_CONTEXT_BLOCK_REF = 9,      /* LL_CONTEXT_BLOCK_REF  */
     LL_CONTEXT_BLOCK_CONTENT = 10, /* LL_CONTEXT_BLOCK_CONTENT  */
     LL_CONTEXT_BLOCK_ARG = 11,     /* LL_CONTEXT_BLOCK_ARG  */
-    LL_CONTEXT_PRAGMA = 12,        /* LL_CONTEXT_PRAGMA  */
-    LL_CONTEXT_FORMAT = 13,        /* LL_CONTEXT_FORMAT  */
-    LL_CONTEXT_TEMPLATE_FUNC = 14, /* LL_CONTEXT_TEMPLATE_FUNC  */
-    LL_CONTEXT_INNER_DEST = 15,    /* LL_CONTEXT_INNER_DEST  */
-    LL_CONTEXT_INNER_SRC = 16,     /* LL_CONTEXT_INNER_SRC  */
-    LL_CONTEXT_CLIENT_PROTO = 17,  /* LL_CONTEXT_CLIENT_PROTO  */
-    LL_CONTEXT_SERVER_PROTO = 18,  /* LL_CONTEXT_SERVER_PROTO  */
-    LL_CONTEXT_OPTIONS = 19,       /* LL_CONTEXT_OPTIONS  */
-    LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
-    LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
-    LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_BLOCK_FUNCARG = 12, /* LL_CONTEXT_BLOCK_FUNCARG  */
+    LL_CONTEXT_PRAGMA = 13,        /* LL_CONTEXT_PRAGMA  */
+    LL_CONTEXT_FORMAT = 14,        /* LL_CONTEXT_FORMAT  */
+    LL_CONTEXT_TEMPLATE_FUNC = 15, /* LL_CONTEXT_TEMPLATE_FUNC  */
+    LL_CONTEXT_INNER_DEST = 16,    /* LL_CONTEXT_INNER_DEST  */
+    LL_CONTEXT_INNER_SRC = 17,     /* LL_CONTEXT_INNER_SRC  */
+    LL_CONTEXT_CLIENT_PROTO = 18,  /* LL_CONTEXT_CLIENT_PROTO  */
+    LL_CONTEXT_SERVER_PROTO = 19,  /* LL_CONTEXT_SERVER_PROTO  */
+    LL_CONTEXT_OPTIONS = 20,       /* LL_CONTEXT_OPTIONS  */
+    LL_CONTEXT_CONFIG = 21,        /* LL_CONTEXT_CONFIG  */
+    LL_CONTEXT_TEMPLATE_REF = 22,  /* LL_CONTEXT_TEMPLATE_REF  */
+    LL_CONTEXT_FILTERX = 23,       /* LL_CONTEXT_FILTERX  */
+    LL_CONTEXT_FILTERX_SIMPLE_FUNC = 24, /* LL_CONTEXT_FILTERX_SIMPLE_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 25,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_FILTERX_FUNC = 26,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_MAX = 27,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
-    KW_OR = 9001,                  /* KW_OR  */
-    KW_AND = 9002,                 /* KW_AND  */
-    KW_STR_EQ = 9003,              /* KW_STR_EQ  */
-    KW_STR_NE = 9004,              /* KW_STR_NE  */
-    KW_TA_EQ = 9005,               /* KW_TA_EQ  */
-    KW_TA_NE = 9006,               /* KW_TA_NE  */
-    KW_TAV_EQ = 9007,              /* KW_TAV_EQ  */
-    KW_TAV_NE = 9008,              /* KW_TAV_NE  */
-    KW_STR_LT = 9009,              /* KW_STR_LT  */
-    KW_STR_LE = 9010,              /* KW_STR_LE  */
-    KW_STR_GE = 9011,              /* KW_STR_GE  */
-    KW_STR_GT = 9012,              /* KW_STR_GT  */
-    KW_TA_LT = 9013,               /* KW_TA_LT  */
-    KW_TA_LE = 9014,               /* KW_TA_LE  */
-    KW_TA_GE = 9015,               /* KW_TA_GE  */
-    KW_TA_GT = 9016,               /* KW_TA_GT  */
-    KW_NOT = 9017,                 /* KW_NOT  */
+    KW_OR = 9010,                  /* KW_OR  */
+    KW_AND = 9020,                 /* KW_AND  */
+    KW_STR_EQ = 9030,              /* KW_STR_EQ  */
+    KW_STR_NE = 9031,              /* KW_STR_NE  */
+    KW_TA_EQ = 9032,               /* KW_TA_EQ  */
+    KW_TA_NE = 9033,               /* KW_TA_NE  */
+    KW_TAV_EQ = 9034,              /* KW_TAV_EQ  */
+    KW_TAV_NE = 9035,              /* KW_TAV_NE  */
+    KW_STR_LT = 9040,              /* KW_STR_LT  */
+    KW_STR_LE = 9041,              /* KW_STR_LE  */
+    KW_STR_GE = 9042,              /* KW_STR_GE  */
+    KW_STR_GT = 9043,              /* KW_STR_GT  */
+    KW_TA_LT = 9044,               /* KW_TA_LT  */
+    KW_TA_LE = 9045,               /* KW_TA_LE  */
+    KW_TA_GE = 9046,               /* KW_TA_GE  */
+    KW_TA_GT = 9047,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9050,         /* KW_PLUS_ASSIGN  */
+    KW_REGEXP_MATCH = 9060,        /* KW_REGEXP_MATCH  */
+    KW_NOT = 9049,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
     KW_PARSER = 10002,             /* KW_PARSER  */
@@ -137,6 +143,7 @@ extern int main_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -263,6 +270,7 @@ extern int main_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -279,7 +287,8 @@ extern int main_debug;
     KW_INCLUDE_BYTES = 10514,      /* KW_INCLUDE_BYTES  */
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
-    KW_FETCH_NO_DATA_DELAY = 10522 /* KW_FETCH_NO_DATA_DELAY  */
+    KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
+    KW_LABELS = 10530              /* KW_LABELS  */
   };
   typedef enum main_tokentype main_token_kind_t;
 #endif
@@ -287,7 +296,7 @@ extern int main_debug;
 #define MAIN_EMPTY -2
 #define MAIN_EOF 0
 #define MAIN_error 256
-#define MAIN_UNDEF 10523
+#define MAIN_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -299,36 +308,42 @@ extern int main_debug;
 #define LL_CONTEXT_BLOCK_REF 9
 #define LL_CONTEXT_BLOCK_CONTENT 10
 #define LL_CONTEXT_BLOCK_ARG 11
-#define LL_CONTEXT_PRAGMA 12
-#define LL_CONTEXT_FORMAT 13
-#define LL_CONTEXT_TEMPLATE_FUNC 14
-#define LL_CONTEXT_INNER_DEST 15
-#define LL_CONTEXT_INNER_SRC 16
-#define LL_CONTEXT_CLIENT_PROTO 17
-#define LL_CONTEXT_SERVER_PROTO 18
-#define LL_CONTEXT_OPTIONS 19
-#define LL_CONTEXT_CONFIG 20
-#define LL_CONTEXT_TEMPLATE_REF 21
-#define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_BLOCK_FUNCARG 12
+#define LL_CONTEXT_PRAGMA 13
+#define LL_CONTEXT_FORMAT 14
+#define LL_CONTEXT_TEMPLATE_FUNC 15
+#define LL_CONTEXT_INNER_DEST 16
+#define LL_CONTEXT_INNER_SRC 17
+#define LL_CONTEXT_CLIENT_PROTO 18
+#define LL_CONTEXT_SERVER_PROTO 19
+#define LL_CONTEXT_OPTIONS 20
+#define LL_CONTEXT_CONFIG 21
+#define LL_CONTEXT_TEMPLATE_REF 22
+#define LL_CONTEXT_FILTERX 23
+#define LL_CONTEXT_FILTERX_SIMPLE_FUNC 24
+#define LL_CONTEXT_FILTERX_ENUM 25
+#define LL_CONTEXT_FILTERX_FUNC 26
+#define LL_CONTEXT_MAX 27
 #define KW_ASSIGN 9000
-#define KW_OR 9001
-#define KW_AND 9002
-#define KW_STR_EQ 9003
-#define KW_STR_NE 9004
-#define KW_TA_EQ 9005
-#define KW_TA_NE 9006
-#define KW_TAV_EQ 9007
-#define KW_TAV_NE 9008
-#define KW_STR_LT 9009
-#define KW_STR_LE 9010
-#define KW_STR_GE 9011
-#define KW_STR_GT 9012
-#define KW_TA_LT 9013
-#define KW_TA_LE 9014
-#define KW_TA_GE 9015
-#define KW_TA_GT 9016
-#define KW_NOT 9017
+#define KW_OR 9010
+#define KW_AND 9020
+#define KW_STR_EQ 9030
+#define KW_STR_NE 9031
+#define KW_TA_EQ 9032
+#define KW_TA_NE 9033
+#define KW_TAV_EQ 9034
+#define KW_TAV_NE 9035
+#define KW_STR_LT 9040
+#define KW_STR_LE 9041
+#define KW_STR_GE 9042
+#define KW_STR_GT 9043
+#define KW_TA_LT 9044
+#define KW_TA_LE 9045
+#define KW_TA_GE 9046
+#define KW_TA_GT 9047
+#define KW_PLUS_ASSIGN 9050
+#define KW_REGEXP_MATCH 9060
+#define KW_NOT 9049
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
 #define KW_PARSER 10002
@@ -342,6 +357,7 @@ extern int main_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -468,6 +484,7 @@ extern int main_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -485,6 +502,7 @@ extern int main_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
+#define KW_LABELS 10530
 
 /* Value type.  */
 #if ! defined MAIN_STYPE && ! defined MAIN_STYPE_IS_DECLARED
